# -*- coding: utf-8 -*-
"""
This module handles the calculation of the characterizing parameters in
accordance with the **ISO 13694** and **ISO 11145**.
"""

# =============================================================================
# Imports
# =============================================================================
import math
import numpy as np

from beamprofiler.iso import measured_quantities as mq
from beamprofiler.utils import data_processing as dp


def fractional_power(raw_data, clip_level):
    """
    `fractional_power` returns the fraction of the clip-level power to the
    total power. In order to avoid errors induced by background noise, it is
    recommended to use as input a noise-corrected dataframe.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    clip_level : float
        0 <= clip_level <= 1. The clip-level defines the clip-level power
        density, and only power densities greater than this threshold value
        are considered in the calculation.

    Returns
    -------
    float64
        0 <= fractional_power <= 1. fractional_power = 1 for a perfect flat-top
        beam.

    """

    return (
        mq.clip_level_power(raw_data, clip_level) /
        mq.total_power(raw_data)
    )


def beam_center(raw_data, raw_header):
    """
    `beam_center` returns the center coordinate of the power density
    distribution. In order to avoid errors induced by background noise, it is
    recommended to use as input a noise-corrected dataframe. The beam center
    is defined as the first-order moment of the power density distribution.

    The center coordinate on the x-axis is defined as:
    M_1,0/M_0,0.
    The center coordinate on the y-axis is defined as
    M_0,1/M_0,0.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    raw_header : dataframe
        header of the power density distribution.

    Returns
    -------
    int
        center coordinate on the x-axis in pixel.
    int
        center coordinate on the y-axis in pixel.

    """

    m_0 = dp.image_moments(raw_data, raw_header, 0, 0, 0, 0)
    m_1x = dp.image_moments(raw_data, raw_header, 1, 0, 0, 0)
    m_1y = dp.image_moments(raw_data, raw_header, 0, 1, 0, 0)

    # Since this is a discrete function the values are rounded and converted
    # to int
    return (
        int(round(m_1x / m_0)),
        int(round(m_1y / m_0))
    )


def beam_width(raw_data, raw_header, beam_center_x, beam_center_y):
    """
    `beam_width` returns the beam width of the power density distribution. In
    order to avoid errors induced by background noise, it is recommended to use
    as input a noise-corrected dataframe. The beam width is defined as four
    times the square root of the second-order moment of the power density
    distribution about the beam center.


    The beam width about the x-axis is defined as:
    4*sqrt(M_2,0 - beam_center_x * M_1,0)
    The beam with about the y-axis is defined as:
    4*sqrt(M_0,2 - beam_center_y * M_0,1).


    Note that this definition comes from the mathematical manipulation and
    simplification of the formula applied in this function. For more
    information, refer to
    https://en.wikipedia.org/wiki/Image_moment#Central_moments

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    raw_header : dataframe
        header of the power density distribution.
    beam_center_x : int
        center coordinate of the power density distribution on the x-axis.
    beam_center_y : int
        center coordinate of the power density distribution on the y-axis.

    Returns
    -------
    float
        beam width about the x-axis in pixel.
    float
        beam width about the y-axis in pixel.

    """

    m_0 = dp.image_moments(raw_data, raw_header, 0, 0, 0, 0)
    m_2x = dp.image_moments(raw_data, raw_header, 2, 0, beam_center_x, 0)
    m_2y = dp.image_moments(raw_data, raw_header, 0, 2, 0, beam_center_y)

    try:
        return (
            round(4 * (math.sqrt(m_2x / m_0)), 4),
            round(4 * (math.sqrt(m_2y / m_0)), 4)
        )
    except ZeroDivisionError:
        return -1, -1


def beam_aspect_ratio(d_x, r_x, d_y, r_y):
    """
    `beam_aspect_ratio` returns the aspect ratio (circularity or squareness) of
    the power density distribution. The beam aspect ratio is defined as:
    beam_width_y / beam_width_x.

    If the pixel resolution about the x- and y-axis are the same, the aspect
    ratio can be calculated using the beam width in pixel or in millimeter.
    However, if the pixel resolution about the x- and y-axis are not the same,
    then the aspect ratio should be calculated using the beam width in
    millimeter. Therefore, this function converts the beam width from pixel to
    millimeter.

    Parameters
    ----------
    d_x : float
        beam width about the x-axis in pixel.
    r_x : float64
        pixel resolution on the x-axis in millimeter per pixel.
    d_y : float
        beam width about the y-axis in pixel.
    r_y : float64
        pixel resolution on the y-axis in millimeter per pixel.

    Returns
    -------
    float64
        beam aspect ratio.

    """

    return (d_y*r_y) / (d_x*r_x)


def clip_level_irradiation_area(raw_data, clip_level):
    """
    `clip_level_irradiation_area` returns the area of the filtered power
    density distribution in pixel. Only power densities that are greater than
    the clip-level power density are considered in the calculation. In order to
    avoid errors induced by background noise, it is recommended to use as input
    a noise-corrected dataframe.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    clip_level : float
        0 <= clip_level <= 1. The clip-level defines the clip-level power
        density, and only power densities greater than this threshold value
        are considered in the calculation.

    Returns
    -------
    int64
        irradiation area considering only power densities that are greater than
        a threshold.

    """

    # The threshold is defined as the clip-level power density
    threshold = mq.clip_level_power_density(raw_data, clip_level)

    # The area is simply the count of pixels that satisfy the condition
    return raw_data[raw_data > threshold].count().sum()


def clip_level_average_power_density(clip_level_power,
                                     clip_level_irradiation_area):
    """
    `clip_level_average_power_density` returns the average power density of the
    filtered power density distribution.

    Parameters
    ----------
    clip_level_power : float64
        total power considering only power densities that are greater than a
        threshold.
    clip_level_irradiation_area : int64
        irradiation area considering only power densities that are greater than
        a threshold.

    Returns
    -------
    float64
        average power density of the filtered power density distribution.

    """

    # The average power density is defined as the power divided by the area
    return clip_level_power / clip_level_irradiation_area


def flatness_factor(clip_level_average_power_density, max_power_density):
    """
    `flatness_factor` returns the flatness factor of the power density
    distribution.

    The flatness factor is defined as the ratio of the clip-level average power
    density to the maximum power density. In other order, the flatness factor
    quantifies how much the average clip-level power density deviates from the
    maximum power density.

    Parameters
    ----------
    clip_level_average_power_density : float64
        average power density of the filtered power density distribution.
    max_power_density : float64
        maximum power density of the power density distribution.

    Returns
    -------
    flat64
        0 < flatness_factor <= 1. The flatness factor equals one for a
        perfectly flat-top power density distribution.

    """

    return clip_level_average_power_density / max_power_density


def beam_uniformity(raw_data, raw_header, clip_level_average_power_density,
                    clip_level_irradiation_area, clip_level_power_density):
    """
    `beam_uniformity` returns the beam uniformity of the power density
    distribution. In order to avoid errors induced by background noise, it is
    recommended to use as input a noise-corrected dataframe.

    The beam uniformity is defined as the normalized root mean square deviation
    of the power density distribution from its clip-level average power
    density.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    raw_header : dataframe
        header of the power density distribution.
    clip_level_average_power_density : flaot64
        average power density of the filtered power density distribution.
    clip_level_irradiation_area : int64
        irradiation area considering only power densities that are greater than
        a threshold.
    clip_level_power_density : float64
        fraction of the maximum power density.

    Returns
    -------
    aux : float64
        0 >= beam_uniformity. The beam uniformity equals zero for a perfectly
        flat-top power density distribution.

    """

    # Variable to keep the sum over the cells that meet the requirement
    aux_sum = 0

    # Convert input_data to numpy array
    raw_data_np = raw_data.to_numpy()

    # Subtract the clip level average power density
    aux = raw_data_np - clip_level_average_power_density

    # Power
    aux = aux**2

    # Loop through all cells in raw_data_pn
    for x in range(dp.get_xPixel(raw_header) - 1):

        for y in range(dp.get_yPixel(raw_header)):

            # Check if the current cell meets the threshold, which is the
            # clip level power density
            if raw_data_np[x][y] >= clip_level_power_density:

                # Sum
                aux_sum = aux_sum + aux[x][y]

    # Divide by the clip level irradiation area
    aux = aux_sum / clip_level_irradiation_area

    # Square root
    aux = np.sqrt(aux)

    # Divide by the clip level power density
    aux = aux / clip_level_average_power_density

    # Return
    return aux


def plateau_uniformity(raw_data, max_power_density, mix):
    """
    `platerau_uniformity` returns the plateau uniformity of the power density
    distribution. In order to avoid errors induced by background noise, it is
    recommended to use as input a noise-corrected dataframe.

    The power density histogram typically shows two peaks: one near the low-end
    of the x-axis and one near the high-end of the x-axis. The plateau
    uniformity is defined as the ratio of the full-width at half maximum (FWHM)
    of the high-end peak to the maximum power density.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    max_power_density : float64
        maximum power density of the power density distribution.
    mix : int
        mix = [1, 2, 3]. `mix` is the number of normal mixtures used in the
        data fitting.

    Returns
    -------
    float64
        0 < plateau_uniformity < 1. The plateau uniformity equals zero for a
        perfectly flat-top power density distribution.

    """

    x, y = dp.normal_mixture(raw_data, mix)

    # Calculates the full width at half maximum. The half_max part is quite
    # straight forward: simply divide the maximum by 2. The full_width part
    # is calculated by getting the size of <y> that is greater or equal
    # than <half_max> and then multiplying by the step size of <x>
    half_max = y.max()/2
    full_width = np.where(y >= half_max)[0].size * (x[1]-x[0])

    # Approximation of the FWHM: 2.355 * std
    return full_width / max_power_density


def edge_steepness(clip_level_irradiation_area_1,
                   clip_level_irradiation_area_2):
    """
    `edge_steepness` returns the edge steepness of the power density
    distribution. The edge steepness is defined as the normalized difference
    between two clip-level irradiation areas, namely the clip-level irradiation
    area 1 (defined by the clip-level 1) and the clip-level irradiation area 2
    (defined by the clip-level 2).

    Note that clip-level 1 < clip-level 2, and consequently irradiation area 1
    > irradiation area 2.

    Parameters
    ----------
    clip_level_irradiation_area_1 : int64
        clip-level irradiation area defined by the clip-level 1.
    clip_level_irradiation_area_2 : int64
        clip-level irradiation area defined by the clip-level 2.

    Returns
    -------
    float64
        0 < edge_steepness < 1. The edge steepness equals zero for a power
        density distribution with perfectly vertical edges.

    """

    if clip_level_irradiation_area_1 < clip_level_irradiation_area_2:
        raise Exception("The clip-level irradiation 1 should be larger than \
                        the clip-level irradiation 2.")

    return (
        (clip_level_irradiation_area_1 - clip_level_irradiation_area_2) /
        clip_level_irradiation_area_1
    )



# -*- coding: utf-8 -*-
"""
This module defines the class `Beam`, which holds all the relevant data related
to the beam analysis.
"""

# =============================================================================
# Imports
# =============================================================================
import os

from beamprofiler.utils import data_processing as dp
from beamprofiler.iso import measured_quantities as mq
from beamprofiler.iso import characterizing_parameters as iso_cp
from beamprofiler.niso import characterizing_parameters as niso_cp


class Beam:
    """
    Class `Beam`.

    There are five categories of instance variables:
    1. defined by the user:
    2. defined in `utils.data_processing.py`
    3. defined in `iso.measured_quantities.py`
    4. defined in `iso.characterizing_parameters.py`
    5. defined in `niso.characterizing_parameters.py`
    """

    def __init__(self, path, fileName, eta, epsilon, mix):
        """
        Initialize an instance of type `Beam` with all relevant data related to
        the beam analysis.

        Parameters
        ----------
        path : str
            path to the power density distribution file.
        fileName : str
            name of the power density distribution file.
        eta : float
            upper clip level. 0 <= eta <= 1.
        epsilon : float
            lower clip level. 0 <= epsilon <= eta <= 1.
        mix : int
            number of normal mixtures used in the normal fit. mix=[1, 2, 3].

        Returns
        -------
        None.
        """

        # =====================================================================
        # Instance variables defined by the user
        # =====================================================================
        self.eta = (
            eta
        )
        self.epsilon = (
            epsilon
        )
        self.mix = (
            mix
        )

        # =====================================================================
        # Instance variables define in utils.data_processing.py
        # =====================================================================
        self.raw_data = (
            dp.raw_data(os.path.join(path, fileName))
        )
        self.raw_header = (
            dp.raw_header(os.path.join(path, fileName))
        )
        self.raw_data_null = (
            dp.remove_background(self.raw_data,
                                 self.raw_header)
        )
        self.xResolution = (
            dp.get_xResolution(self.raw_header)
        )
        self.yResolution = (
            dp.get_yResolution(self.raw_header)
        )

        # =====================================================================
        # Instance variables defined in iso.measure_quantities.py
        # =====================================================================
        self.maxPowerDensity = (
            mq.max_power_density(self.raw_data_null)
        )
        self.totalPower = (
            mq.total_power(self.raw_data_null)
        )
        self.powerDensity_eta = (
            mq.clip_level_power_density(self.raw_data_null,
                                        self.eta)
        )
        self.power_eta = (
            mq.clip_level_power(self.raw_data_null,
                                self.eta)
        )

        # =====================================================================
        # Instance variables defined in iso.characterizing_parameters.py
        # =====================================================================
        self.fractionalPower_eta = (
            iso_cp.fractional_power(self.raw_data_null,
                                    self.eta)
        )
        self.centerX, self.centerY = (
            iso_cp.beam_center(self.raw_data_null.T,
                               self.raw_header)
        )
        self.widthX, self.widthY = (
            iso_cp.beam_width(self.raw_data_null.T,
                              self.raw_header,
                              self.centerX,
                              self.centerY)
        )
        self.aspectRatio = (
            iso_cp.beam_aspect_ratio(self.widthX,
                                     self.xResolution,
                                     self.widthY,
                                     self.yResolution)
        )
        self.irradiationArea_eta = (
            iso_cp.clip_level_irradiation_area(self.raw_data_null,
                                               self.eta)
        )
        self.irradiationArea_epsilon = (
            iso_cp.clip_level_irradiation_area(self.raw_data_null,
                                               self.epsilon)
        )
        self.averagePowerDensity_eta = (
            iso_cp.clip_level_average_power_density(self.power_eta,
                                                    self.irradiationArea_eta)
        )
        self.flatnessFactor_eta = (
            iso_cp.flatness_factor(self.averagePowerDensity_eta,
                                   self.maxPowerDensity)
        )
        self.beamUniformity_eta = (
            iso_cp.beam_uniformity(self.raw_data_null,
                                   self.raw_header,
                                   self.averagePowerDensity_eta,
                                   self.irradiationArea_eta,
                                   self.powerDensity_eta)
        )
        self.plateauUniformity_eta = (
            iso_cp.plateau_uniformity(self.raw_data_null,
                                      self.maxPowerDensity,
                                      self.mix)
        )
        self.edgeSteepness_eta = (
            iso_cp.edge_steepness(self.irradiationArea_epsilon,
                                  self.irradiationArea_eta)
        )

        # =====================================================================
        # Instance variables defined in niso.characterizing_parameters.py
        # =====================================================================
        self.widthX_eta = (
            niso_cp.clip_level_beam_width(self.raw_data_null.T,
                                          self.eta)
        )
        self.widthY_eta = (
            niso_cp.clip_level_beam_width(self.raw_data_null,
                                          self.eta)
        )
        self.edgeX_epsilon_eta = (
            niso_cp.clip_level_edge_width(self.raw_data_null.T,
                                          self.epsilon,
                                          self.eta)
        )
        self.edgeY_epsilon_eta = (
            niso_cp.clip_level_edge_width(self.raw_data_null,
                                          self.epsilon,
                                          self.eta)
        )
        self.modPlateauUniformity_eta = (
            niso_cp.plateau_uniformity(self.raw_data_null,
                                       self.mix)
        )
        self.topHatFactor = (
            niso_cp.top_hat_factor(dp.pre_top_hat(self.raw_data))
        )



"""
`BeamProfiler` is a Python package for laser beam analysis and
characterization according to ISO 13694, ISO 11145, and other non-ISO
definitions commonly used in the industry.
"""


__author__ = """Wagno Alves Braganca Junior"""
__email__ = 'wagnojunior@gmail.com'
__version__ = '1.0.1'


# =============================================================================
# Imports
# =============================================================================
from beamprofiler.beam import Beam
from beamprofiler import iso
from beamprofiler import niso
from beamprofiler import utils

__all__ = ['Beam', 'iso', 'niso', 'utils']



# -*- coding: utf-8 -*-
"""
This module handles the calculation of the characterizing parameters in
accordance with non-ISO definitions.
"""

# =============================================================================
# Imports
# =============================================================================
import numpy as np
from scipy import stats

from beamprofiler.iso import measured_quantities as mq
from beamprofiler.utils import data_processing as dp


def plateau_uniformity(raw_data, mix):
    """
    `plateau_uniformity` returns the plateau uniformity of the power density
    distribution. In order to avoid errors induced by background noise, it is
    recommended to use as input a noise-corrected dataframe.

    The power density histogram typically shows two peaks: one near the low-end
    of the x-axis and one near the high-end of the x-axis. The plateau
    uniformity is defined as the ratio of the full-width at half maximum (FWHM)
    of the high-end peak to the energy density value corresponding to the
    maximum.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    mix : int
        mix = [1, 2, 3]. `mix` is the number of normal mixtures used in the
        data fitting.

    Returns
    -------
    float64
        0 < plateau_uniformity < 1. The plateau uniformity equals zero for a
        perfectly flat-top power density distribution.

    """

    x, y = dp.normal_mixture(raw_data, mix)

    # Calculates the full width at half maximum. The half_max part is quite
    # straight forward: simply divide the maximum by 2. The full_width part
    # is calculated by getting the size of <y> that is greater or equal
    # than <half_max> and then multiplying by the step size of <x>
    half_max = y.max()/2
    full_width = np.where(y >= half_max)[0].size * (x[1]-x[0])

    # Get the index of the maximum value and the corresponding energy density
    power_density_max = x[np.argmax(y)]

    # Approximation of the FWHM: 2.355 * std
    return full_width / power_density_max


def clip_level_beam_width(raw_data, clip_level):
    """
    `clip_level_beam_width` returns the clip-level beam width of the filtered
    power density distribution in pixel. Only power densities that are greater
    than the clip-level power density are considered in the calculation. In
    order to avoid errors induced by background noise, it is recommended to use
    as input a noise-corrected dataframe.

    The clip-level beam width is defined as the count of pixels that have a
    power density greater than the clip-level power density. The clip-level
    beam width about the x axis is computed by iterating along the row indices
    and the clip-level beam width about the y axis is computed by iterating
    along the column indices. The results for each axis are then averaged out
    disregarding the zeros and any eventual outliers.

    The use of a high-pixel resolution is recommended in order to avoid
    quantization errors that may arise from counting pixels. Transpose raw_data
    to get the result along the x-axis.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    clip_level : float
        0 <= clip_level <= 1. The clip-level defines the clip-level power
        density, and only power densities greater than this threshold value
        are considered in the calculation.

    Returns
    -------
    float64
        clip-level beam width of the filtered power density distribution in
        pixel.

    """

    # Threshold power density
    threshold = mq.clip_level_power_density(raw_data, clip_level)

    # Transpose raw_data to get the result along the x-axis
    beam_width = (raw_data > threshold).apply(np.count_nonzero)

    # Remove zero values
    beam_width = beam_width[beam_width > 0]

    # Filter out outliers 2 times
    for i in range(2):

        # Identify the outliers by calculating the z-score
        zScore = np.abs(stats.zscore(beam_width))

        # Check if zScore is filled with NaN (in case beam_width is filled
        # with the same values)
        # A RunTimeWarning is thrown when this condition is met
        if np.isnan(zScore).any():

            # If yes, then fill zScore with the value 1
            np.nan_to_num(zScore, copy=False, nan=1)

        # Get only values that have a z-score of less than or equal to 2
        beam_width = beam_width[zScore <= 1]

        # Check if edge_width is empty (in case of a perfect distribution)
        if beam_width.size == 0:

            # If yes, then add one entry equals to zero
            beam_width[0] = 0

            break

    # Return the average clip-level beam width
    return np.average(beam_width)


def clip_level_edge_width(raw_data, clip_level_1, clip_level_2):
    """
    `clip_level_edge_width` returns the clip-level edge width of the filtered
    power density distribution in pixel. Only power densities that are greater
    than the clip-level power density are considered in the calculation. In
    order to avoid errors induced by background noise, it is recommended to use
    as input a noise-corrected dataframe.

    The clip-level edge width is defined as the count of pixels that have a
    power density greater than the clip-level power density 1 (defined by the
    clip-level 1) AND lower than the clip-level power density 2 (defined by the
    clip-level 2). The clip-level edge width about the x-axis is computed by
    iterating along the row indices and the clip-level beam width about the
    y-axis is computed by iterating along the column indices. The results for
    each axis are then averaged out disregarding the zeros and any eventual
    outliers.

    The use of a high-pixel resolution is recommended in order to avoid
    quantization errors that may arise from counting pixels. Note that
    clip_level_1 < clip_level 2. Transpose raw_data to get the result along the
    x-axis.

    Parameters
    ----------
    raw_data : dataframe
        noise-corrected power density distribution.
    clip_level_1 : int64
        0 <= clip_level_1 <= 1. The clip-level defines the clip-level power
        density, and only power densities greater than this threshold value
        are considered in the calculation.
    clip_level_2 : TYPE
        0 <= clip_level_2 <= 1. The clip-level defines the clip-level power
        density, and only power densities less than this threshold value
        are considered in the calculation.

    Returns
    -------
    float64
        clip-level edge width of the filtered power density distribution in
        pixel.

    """

    # Threshold power density LOW value
    threshold_1 = mq.clip_level_power_density(raw_data, clip_level_1)

    # Threshold power density HIGH value
    threshold_2 = mq.clip_level_power_density(raw_data, clip_level_2)

    # Transpose raw_data to get the result along the x-axis
    edge_width = (
        ((raw_data > threshold_1) & (raw_data < threshold_2))
        .apply(np.count_nonzero)
    )

    # Remove zero values
    edge_width = edge_width[edge_width > 0]

    # Filter out outliers 2 times
    for i in range(2):

        # Identify the outliers by calculating the z-score
        zScore = np.abs(stats.zscore(edge_width))

        # Check if zScore is filled with NaN (in case beam_width is filled
        # with the same values)
        # A RunTimeWarning is thrown when this condition is met
        if np.isnan(zScore).any():

            # If yes, then fill zScore with the value 1
            np.nan_to_num(zScore, copy=False, nan=1)

        # Get only values that have a z-score of less than or equal to 2
        edge_width = edge_width[zScore <= 1]

        # Check if edge_width is empty (in case of a perfect distribution)
        if edge_width.size == 0:

            # If yes, then add one entry equals to zero
            edge_width[0] = 0

            break

    # Return the average clip-level beam width
    return np.average(edge_width) / 2


def top_hat_factor(df):
    """
    `top_hat_factor` returns the top-hat factor of the normalized energy curve,
    which is generated from the power density distribution. In order to avoid
    errors induced by background noise, it is recommended to use as input a
    noise-corrected dataframe.

    Parameters
    ----------
    df : dataframe
        dataframe that contains, among other things, the normalized cumulative
        energy.

    Returns
    -------
    thf : float
        top-hat factor.

    """

    # Get the x-axis step of the normalized energy curve. Because this curve
    # curve is normalized, the length is 100 and therefore the step is 100
    # divided by the length of the data
    step = 100 / len(df)

    # Get the total sum from the normalized energy fraction
    total_sum = df.sum()['Normalized Cumulative Energy'] * step

    # The top-hat factor is the ratio of the total area (100 * 100) to the
    # area under the normalized energy curve. Multiply by 100 to get the
    # percentage value
    thf = total_sum / (10000)

    return thf



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst', encoding='utf-8') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst', encoding='utf-8') as history_file:
    history = history_file.read()

requirements = [
    'cycler',
    'fonttools',
    'joblib',
    'kiwisolver',
    'matplotlib',
    'numpy',
    'packaging',
    'pandas',
    'pillow',
    'pyparsing',
    'python-dateutil',
    'pytz',
    'scikit-learn',
    'scipy',
    'six',
    'threadpoolctl',
    'xlsxwriter'
]

test_requirements = []

setup(
    author="Wagno Alves Braganca Jr.",
    author_email='wagnojunior@gmail.com',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="BeamProfiler is a Python package for laser beam analysis and characterization according to ISO 13694, ISO 11145, and other non-ISO definitions commonly used in the industry.",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description_content_type='text/x-rst',
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='beamprofiler',
    name='beamprofiler',
    packages=find_packages(
        include=['beamprofiler', 'beamprofiler.*'],
        where='src'),
    package_dir={'': 'src'},
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/wagnojunior/beamprofiler',
    version='1.0.1',
    zip_safe=False,
)
